0.9.9 API documentation: GLM_EXT_vector_int1_precision

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Typedefs
GLM_EXT_vector_int1_precision
Stable extensions

Exposes highp_ivec1, mediump_ivec1 and lowp_ivec1 types. More...

## Typedefs
typedef vec< 1, int, highp > | highp_ivec1
| 1 component vector of signed integer values.
typedef vec< 1, int, lowp > | lowp_ivec1
| 1 component vector of signed integer values.
typedef vec< 1, int, mediump > | mediump_ivec1
| 1 component vector of signed integer values.

## Detailed Description

Exposes highp_ivec1, mediump_ivec1 and lowp_ivec1 types.

Include <glm/ext/vector_int1_precision.hpp> to use the features of this extension.